import Chip from '../chip/Chip';
import Input from '../input/Input';
import Popover from '../popover/Popover';
import { ListItemProps, ListOnlyProps } from './../list/List';
interface Translation {
    empty?: string;
    search?: string;
}
export interface SelectOption extends Partial<ListItemProps> {
    value: string | number;
    label: string;
}
export interface SelectProps extends Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange' | 'placeholder'> {
    /** Select options (default: []) */
    options?: SelectOption[];
    /** The default value. Use when the component is controlled. */
    value?: any;
    /** The default value. Use when the component is not controlled. */
    defaultValue?: any;
    /** Control open select menu (default: false) */
    open?: boolean;
    /** The variant to use (default: outlined) */
    variant?: 'outlined' | 'filled';
    /** The size of the component. (default: medium) */
    size?: 'small' | 'medium' | 'large';
    /** The shape of select (default: rounded ~ 8px) */
    shape?: 'square' | 'rounded' | 'circle' | number;
    /** input placeholder */
    placeholder?: React.ReactNode;
    /** Attributes applied to the input element. */
    inputProps?: React.HTMLProps<HTMLInputElement>;
    /** Whether allow search (default: false) */
    searchable?: boolean;
    /** If true, the component is disabled. (default: false) */
    disabled?: boolean;
    /** If true, the label is displayed in an error state (default: false) */
    error?: boolean;
    /** If true, the input will take up the full width of its container. (default: false) */
    fullWidth?: boolean;
    /** If true, a textarea element is rendered instead of an input. (default: false) */
    multiple?: boolean;
    /** Maximum number of tag to show, set -1 to unlimited (default: -1) */
    limit?: number;
    /** Whether allow clear	 */
    allowClear?: boolean;
    /** Override select menu */
    OptionMenu?: React.ReactNode;
    /** Customize popover props */
    PopoverProps?: Partial<React.ComponentProps<typeof Popover>>;
    /** Customize menu options */
    MenuListProps?: Partial<ListOnlyProps>;
    /** Customize search box */
    SearchInputProps?: Partial<React.ComponentProps<typeof Input>>;
    /** Customize chip in multiple mode */
    ChipProps?: Partial<React.ComponentProps<typeof Chip>>;
    /** Add more options at the start of the options list */
    StartAdditional?: React.ReactNode;
    /** Add more options at the end of the options list */
    EndAdditional?: React.ReactNode;
    /** Custom clear icon */
    ClearIcon?: React.ReactNode;
    /** Custom end icon (default: arrow icon) */
    renderEndIcon?: (open: boolean, className: string) => React.ReactNode;
    /** Customize how the component renders, return ListItemProps type */
    renderOption?: (option: SelectOption) => ListItemProps;
    /** Customize how the value render */
    renderValue?: (value: any) => React.ReactNode;
    /** Trigger when select change
     * value = input value (string | number)
     * valueArr = value type = array
     * option = option is clicked
     */
    onChange?: (value: any, valueArr: any[], option?: SelectOption) => any;
    /** Trigger when search box change */
    onSearch?: (keyword: string) => any;
    /** Support translate language */
    translation?: Translation;
    /** The ref is forwarded to the root element. */
    ref?: React.Ref<HTMLDivElement>;
    /** The ref is forwarded to the input element. */
    inputRef?: React.Ref<HTMLInputElement>;
}
export {};
